# th2 common library (Python)

`th2-common-py` is an API for all th2 components created with Python.
Check the [Wiki](https://github.com/th2-net/th2-common-py/wiki) for instructions and examples.

## Installation
```
pip install th2-common
```
This package can be found on [PyPI](https://pypi.org/project/th2-common/ "th2 common library").
